@@ -223,6 +223,8 @@ mod test {
             ("{}{a:b}", vec![(0, "{}"), (2, "{a:b}")]),
             // fuck
             // ("[1, 2, 3] {[} (4, 5, 6) ]", vec![(0, "[1, 2, 3]"), (14, "(4, 5, 6)")]),
+            (r#"[ "\"]" ]"#, vec![(0, r#"[ "\"]" ]"#)]),
+            (r#"[[ "\"]" ]"#, vec![(1, r#"[ "\"]" ]"#)]),
         ];
         for (t, res) in cases {
             let input = t.chars().collect::<Vec<_>>();
